================
Readme Data Sets
================

The data sets shipped with the **articubench** benchmark are subsets of the
whole data sets. To get the full data sets you can follow the descriptions
below. Be aware that some of the full data sets are not completely free but are
restricted to scientific research only. The subsets published here should be
free to use.


common_voice
============


babibabubaba
============


KEC
===


GECO
====

